@@ -823,10 +823,9 @@ void ProjectClip::doExtractImage()
     int fullWidth = (int)((double) 150 * prod->profile()->dar() + 0.5);
     QDir thumbFolder(bin()->projectFolder().path() + "/thumbs/");
     int max = prod->get_length();
-    int pos;
     while (!m_requestedThumbs.isEmpty()) {
         m_thumbMutex.lock();
-        pos = m_requestedThumbs.takeFirst();
+        int pos = m_requestedThumbs.takeFirst();
         m_thumbMutex.unlock();
         if (thumbFolder.exists(hash() + '#' + QString::number(pos) + ".png")) {
             emit thumbReady(pos, QImage(thumbFolder.absoluteFilePath(hash() + '#' + QString::number(pos) + ".png")));
@@ -938,7 +937,7 @@ void ProjectClip::slotCreateAudioThumbs()
         // convert cached image
         int n = image.width() * image.height();
         for (int i = 0; i < n; i++) {
-            QRgb p = image.pixel(i / 2, i % channels);
+            QRgb p = image.pixel(i / channels, i % channels);
             audioLevels << qRed(p);
             audioLevels << qGreen(p);
             audioLevels << qBlue(p);
@@ -952,46 +951,48 @@ void ProjectClip::slotCreateAudioThumbs()
 
     if (KdenliveSettings::ffmpegaudiothumbnails() && m_type != Playlist) {
         QStringList args;
-        QTemporaryFile tmpfile;
-        if (!tmpfile.open()) {
-            bin()->emitMessage(i18n("Cannot create temporary file, check disk space and permissions"), ErrorMessage);
-            return;
+        QList <QTemporaryFile*> channelFiles;
+        for (int i = 0; i < channels; i++) {
+            QTemporaryFile *channelTmpfile = new QTemporaryFile;
+            if (!channelTmpfile->open()) {
+                bin()->emitMessage(i18n("Cannot create temporary file, check disk space and permissions"), ErrorMessage);
+                return;
+            }
+            channelTmpfile->close();
+            channelFiles << channelTmpfile;
         }
-        QTemporaryFile tmpfile2;
-        if (!tmpfile2.open()) {
-            bin()->emitMessage(i18n("Cannot create temporary file, check disk space and permissions"), ErrorMessage);
-            return;
-        }
-        tmpfile.close();
-        tmpfile2.close();
         args << QStringLiteral("-i") << QUrl::fromLocalFile(prod->get("resource")).path();
 
         bool isFFmpeg = KdenliveSettings::ffmpegpath().contains("ffmpeg");
 
         if (channels == 1) {
             if (isFFmpeg) {
-                args << QStringLiteral("-ac") << QString::number(channels);
                 args << QStringLiteral("-filter_complex:a") << QStringLiteral("aformat=channel_layouts=mono,aresample=async=100");
-                args << QStringLiteral("-map") << QStringLiteral("0:a%1").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< tmpfile.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("0:a%1").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< channelFiles[0]->fileName();
             } else {
                 args << QStringLiteral("-filter_complex:a") << QStringLiteral("aformat=channel_layouts=mono:sample_rates=100");
-                args << QStringLiteral("-map") << QStringLiteral("0:a%1").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< tmpfile.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("0:a%1").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< channelFiles[0]->fileName();
             }
-        } else {
+        } else if (channels == 2) {
             if (isFFmpeg) {
-                //args << QStringLiteral("-ac") << QString::number(channels);
                 args << QStringLiteral("-filter_complex:a") << QStringLiteral("[0:a%1]aresample=async=100,channelsplit=channel_layout=stereo[0:0][0:1]").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "");
                 // Channel 1
-                args << QStringLiteral("-map") << QStringLiteral("[0:1]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< tmpfile.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("[0:1]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< channelFiles[0]->fileName();
                 // Channel 2
-                args << QStringLiteral("-map") << QStringLiteral("[0:0]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< tmpfile2.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("[0:0]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< channelFiles[1]->fileName();
             } else {
                 args << QStringLiteral("-filter_complex:a") << QStringLiteral("[0:a%1]aformat=sample_rates=100,channelsplit=channel_layout=stereo[0:0][0:1]").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "");
                 // Channel 1
-                args << QStringLiteral("-map") << QStringLiteral("[0:1]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< tmpfile.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("[0:1]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< channelFiles[0]->fileName();
                 // Channel 2
-                args << QStringLiteral("-map") << QStringLiteral("[0:0]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< tmpfile2.fileName();
+                args << QStringLiteral("-map") << QStringLiteral("[0:0]") << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("s16le")<< channelFiles[1]->fileName();
             }
+        } else if (channels == 6) {
+            args << QStringLiteral("-filter_complex:a") << QStringLiteral("[0:a%1]aresample=async=100,channelsplit=channel_layout=5.1[0:0][0:1][0:2][0:3][0:4][0:5]").arg(audioStream > 0 ? ":" + QString::number(audioStream) : "");
+                for (int i = 0; i < channels; i++) {
+                    // Channel 1
+                    args << QStringLiteral("-map") << QStringLiteral("[0:%1]").arg(i) << QStringLiteral("-c:a") << QStringLiteral("pcm_s16le") << QStringLiteral("-y") << QStringLiteral("-f") << QStringLiteral("data")<< channelFiles[i]->fileName();
+                }
         }
         emit updateJobStatus(AbstractClipJob::THUMBJOB, JobWaiting, 0);
         QProcess audioThumbsProcess;
@@ -1012,46 +1013,55 @@ void ProjectClip::slotCreateAudioThumbs()
             bin()->emitMessage(i18n("Crash in %1 - creating audio thumbnails", KdenliveSettings::ffmpegpath()), ErrorMessage);
             return;
         }
-        tmpfile.open();
-        QByteArray res = tmpfile.readAll();
-        tmpfile.close();
-        if (res.size() == 0) {
-            emit updateJobStatus(AbstractClipJob::THUMBJOB, JobDone, 0);
-            bin()->emitMessage(i18n("Error reading audio thumbnail"), ErrorMessage);
-            return;
-        }
-        const qint16* raw = (const qint16*) res.constData();
-        const qint16* raw2;
-        QByteArray res2;
+
+        int dataSize = 0;
+        QList <const qint16*> rawChannels;
+        QList <QByteArray> sourceChannels;
         QList<qint16> data2;
-        if (channels > 1) {
-            tmpfile2.open();
-            res2 = tmpfile2.readAll();
-            tmpfile2.close();
-            raw2 = (const qint16*) res2.constData();
+        for (int i = 0; i < channelFiles.count(); i++) {
+            channelFiles[i]->open();
+            QByteArray res = channelFiles[i]->readAll();
+            channelFiles[i]->close();
+            if (dataSize == 0) {
+                dataSize = res.size();
+            }
+            if (res.isEmpty() || res.size() != dataSize) {
+                // Something went wrong, abort
+                emit updateJobStatus(AbstractClipJob::THUMBJOB, JobDone, 0);
+                bin()->emitMessage(i18n("Error reading audio thumbnail"), ErrorMessage);
+                return;
+            }
+            rawChannels << (const qint16*) res.constData();
+            // We need to keep res2 alive or rawChannels data will die
+            sourceChannels << res;
         }
         int progress = 0;
-        double offset = (double) res.size() / (2 * lengthInFrames);
-        int pos = 0;
+        QList <long> channelsData;
+        double offset = (double) dataSize / (2.0 * lengthInFrames);
+        int intraOffset = 1;
+        if (offset > 1000) {
+            intraOffset = offset / 60;
+        } else if (offset > 250) {
+            intraOffset = offset / 10;
+        }
+        double factor = 800.0 / 32768;
         for (int i = 0; i < lengthInFrames; i++) {
-            long c1 = 0;
-            long c2 = 0;
-            pos = (int) (i * offset);
-            int steps = 0;
-            for (int j = 0; j < (int) offset && (pos + j < res.size()); j++) {
-                steps ++;
-                c1 += abs(raw[pos + j]);
-                if (channels > 1) {
-                    c2 += abs(raw2[pos + j]);
-                }
+            channelsData.clear();
+            for (int k = 0; k < rawChannels.count(); k++) {
+                channelsData << 0;
             }
-            if (steps) c1 /= steps;
-            c1 = c1 * 800 / 32768.0;
-            audioLevels << (double) c1;
-            if (channels > 1) {
-                if (steps) c2 /= steps;
-                c2 = c2 * 800 / 32768.0;
-                audioLevels << (double)c2;
+            int pos = (int) (i * offset);
+            int steps = 0;
+            for (int j = 0; j < (int) offset && (pos + j < dataSize); j += intraOffset) {
+                steps ++;
+                for (int k = 0; k < rawChannels.count(); k++) {
+                    channelsData[k] += abs(rawChannels[k][pos + j]);
+                }
+
+            }
+            for (int k = 0; k < channelsData.count(); k++) {
+                if (steps) channelsData[k] /= steps;
+                audioLevels << channelsData[k] * factor;
             }
             int p = i * 100 / lengthInFrames;
             if (p != progress) {
@@ -1087,9 +1097,8 @@ void ProjectClip::slotCreateAudioThumbs()
             keys << "meta.media.audio_level." + QString::number(i);
         }
 
-        int val = 0;
         for (int z = 0;z < lengthInFrames && !m_abortAudioThumb; ++z) {
-            val = (int)(100.0 * z / lengthInFrames);
+            int val = (int)(100.0 * z / lengthInFrames);
             if (last_val != val) {
                 emit updateJobStatus(AbstractClipJob::THUMBJOB, JobWorking, val);
                 last_val = val;
@@ -1118,7 +1127,7 @@ void ProjectClip::slotCreateAudioThumbs()
     if (!m_abortAudioThumb && audioLevels.size() > 0) {
         // Put into an image for caching.
         int count = audioLevels.size();
-        QImage image((count + 3) / 4 / channels, channels, QImage::Format_ARGB32);
+        QImage image(lrint((count + 3) / 4.0 / channels), channels, QImage::Format_ARGB32);
         int n = image.width() * image.height();
         for (int i = 0; i < n; i ++) {
             QRgb p; 
@@ -1132,7 +1141,7 @@ void ProjectClip::slotCreateAudioThumbs()
                 int a = last;
                 p = qRgba(r, g, b, a);
             }
-            image.setPixel(i / 2, i % channels, p);
+            image.setPixel(i / channels, i % channels, p);
         }
         image.save(audioPath);
     }
