@@ -32,11 +32,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QFuture>
 
 class ProjectFolder;
+class AudioStreamInfo;
 class QDomElement;
 class ClipController;
 class ClipPropertiesController;
 class ProjectSubClip;
 class QUndoCommand;
+
 namespace Mlt {
   class Producer;
   class Properties;
@@ -205,6 +207,10 @@ public:
     void abortAudioThumbs();
     /** @brief Returns the list of this clip's subclip's ids. */
     QStringList subClipIds() const;
+    /** @brief Delete cached audio thumb - needs to be recreated */
+    void discardAudioThumb();
+    /** @brief Get path for this clip's audio thumbnail */
+    const QString getAudioThumbPath(AudioStreamInfo *audioInfo);
 
 public slots:
     void updateAudioThumbnail(QVariantList audioLevels);
