@@ -22,6 +22,7 @@
 #define DOCUMENTCHECKER_H
 
 #include "ui_missingclips_ui.h"
+#include "definitions.h"
 
 
 #include <QDir>
@@ -63,7 +64,7 @@ private:
     QDomDocument m_doc;
     Ui::MissingClips_UI m_ui;
     QDialog *m_dialog;
-    QString searchPathRecursively(const QDir &dir, const QString &fileName) const;
+    QString searchPathRecursively(const QDir &dir, const QString &fileName, ClipType type = Unknown) const;
     QString searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash, const QString &fileName) const;
     void checkStatus();
     QMap <QString, QString> m_missingTitleImages;
