@@ -325,7 +325,7 @@ QDomDocument KdenliveDoc::createEmptyDocument(int videotracks, int audiotracks)
         audioTrack.isMute = false;
         audioTrack.isBlind = true;
         audioTrack.isLocked = false;
-        audioTrack.trackName = QStringLiteral("Audio ") + QString::number(audiotracks - i);
+        audioTrack.trackName = i18n("Audio %1", audiotracks - i);
         audioTrack.duration = 0;
         audioTrack.effectsList = EffectsList(true);
         tracks.append(audioTrack);
@@ -337,7 +337,7 @@ QDomDocument KdenliveDoc::createEmptyDocument(int videotracks, int audiotracks)
         videoTrack.isMute = false;
         videoTrack.isBlind = false;
         videoTrack.isLocked = false;
-        videoTrack.trackName = QStringLiteral("Video ") + QString::number(videotracks - i);
+        videoTrack.trackName = i18n("Video %1", i + 1);
         videoTrack.duration = 0;
         videoTrack.effectsList = EffectsList(true);
         tracks.append(videoTrack);
@@ -763,6 +763,11 @@ MltVideoProfile KdenliveDoc::mltProfile() const
     return m_profile;
 }
 
+bool KdenliveDoc::profileChanged(const QString &profile) const
+{
+    return m_profile.toList() != ProfilesDialog::getVideoProfile(profile).toList();
+}
+
 ProfileInfo KdenliveDoc::getProfileInfo() const
 {
         ProfileInfo info;
@@ -959,26 +964,6 @@ bool KdenliveDoc::addClip(QDomElement elem, const QString &clipId)
     return true; */
 }
 
-void KdenliveDoc::setNewClipResource(const QString &id, const QString &path)
-{
-    QDomNodeList prods = m_document.elementsByTagName(QStringLiteral("producer"));
-    int maxprod = prods.count();
-    for (int i = 0; i < maxprod; ++i) {
-        QDomNode m = prods.at(i);
-        QString prodId = m.toElement().attribute(QStringLiteral("id"));
-        if (prodId == id || prodId.startsWith(id + '_')) {
-            QDomNodeList params = m.childNodes();
-            for (int j = 0; j < params.count(); ++j) {
-                QDomElement e = params.item(j).toElement();
-                if (e.attribute(QStringLiteral("name")) == QLatin1String("resource")) {
-                    e.firstChild().setNodeValue(path);
-                    break;
-                }
-            }
-        }
-    }
-}
-
 QString KdenliveDoc::searchFileRecursively(const QDir &dir, const QString &matchSize, const QString &matchHash) const
 {
     QString foundFileName;
@@ -1222,14 +1207,6 @@ void KdenliveDoc::updateProjectFolderPlacesEntry()
     }
 }
 
-QStringList KdenliveDoc::getExpandedFolders()
-{
-    QStringList result = m_documentProperties.value(QStringLiteral("expandedfolders")).split(';');
-    // this property is only needed once when opening project, so clear it now
-    m_documentProperties.remove(QStringLiteral("expandedfolders"));
-    return result;
-}
-
 const QSize KdenliveDoc::getRenderSize() const
 {
     QSize size;
