@@ -35,15 +35,45 @@
 #include <QApplication>
 #include <QTextBlock>
 
+MyQGraphicsEffect::MyQGraphicsEffect(QObject *parent) :
+    QGraphicsEffect(parent)
+    , m_xOffset(0)
+    , m_yOffset(0)
+    , m_blur(0)
+{
+}
+
+void MyQGraphicsEffect::setShadow(QImage image)
+{
+    m_shadow = image;
+}
+
+void MyQGraphicsEffect::setOffset(int xOffset, int yOffset, int blur)
+{
+    m_xOffset = xOffset;
+    m_yOffset = yOffset;
+    m_blur = blur;
+    updateBoundingRect();
+}
+
+void MyQGraphicsEffect::draw(QPainter *painter)
+{
+    painter->fillRect(boundingRect(), Qt::transparent);
+    painter->drawImage(-2 * m_blur + m_xOffset, -2 * m_blur + m_yOffset, m_shadow);
+    drawSource(painter);
+}
+
+
 MyTextItem::MyTextItem(const QString &txt, QGraphicsItem *parent) :
     QGraphicsTextItem(txt, parent)
     , m_alignment(Qt::AlignLeft)
-    , m_useShadow(false)
 {
     setCacheMode(QGraphicsItem::ItemCoordinateCache);
     setFlag(QGraphicsItem::ItemSendsGeometryChanges, true);
     document()->setDocumentMargin(0);
     updateGeometry();
+    m_shadowEffect = new MyQGraphicsEffect(this);
+    setGraphicsEffect(m_shadowEffect);
     connect(document(), SIGNAL(contentsChange(int, int, int)),
             this, SLOT(updateGeometry(int, int, int)));
 }
@@ -58,7 +88,8 @@ void MyTextItem::updateShadow(bool enabled, int blur, int xoffset, int yoffset,
     m_shadowOffset = QPoint(xoffset, yoffset);
     m_shadowBlur = blur;
     m_shadowColor = color;
-    m_useShadow = enabled;
+    m_shadowEffect->setEnabled(enabled);
+    m_shadowEffect->setOffset(xoffset, yoffset, blur);
     updateShadow();
     update();
 }
@@ -66,7 +97,7 @@ void MyTextItem::updateShadow(bool enabled, int blur, int xoffset, int yoffset,
 QStringList MyTextItem::shadowInfo() const
 {
     QStringList info;
-    info << QString::number(m_useShadow) << m_shadowColor.name(QColor::HexArgb) << QString::number( m_shadowBlur) << QString::number(m_shadowOffset.x()) << QString::number(m_shadowOffset.y());
+    info << QString::number(m_shadowEffect->isEnabled()) << m_shadowColor.name(QColor::HexArgb) << QString::number( m_shadowBlur) << QString::number(m_shadowOffset.x()) << QString::number(m_shadowOffset.y());
     return info;
 }
 
@@ -108,16 +139,17 @@ void MyTextItem::updateGeometry(int, int, int)
         cursor.setPosition(position);           // restore cursor position
         setTextCursor(cursor);
     }
-    if (m_useShadow) {
+    if (m_shadowEffect->isEnabled()) {
         updateShadow();
     }
+    update();
 }
 
 void MyTextItem::updateShadow()
 {
     QString text = toPlainText();
     if (text.isEmpty()) {
-        m_shadow = QImage();
+        m_shadowEffect->setShadow(QImage());
         return;
     }
     QFontMetrics metrics(font());
@@ -145,17 +177,18 @@ void MyTextItem::updateShadow()
     }
     // Calculate position of text in parent item
     QRectF pathRect = QRectF(0, 0, bounding.width(), linePos - lineSpacing + metrics.descent() );
-    QPointF offset = bounding.center() - pathRect.center() + m_shadowOffset;
+    QPointF offset = bounding.center() - pathRect.center() + QPointF(2 * m_shadowBlur, 2 * m_shadowBlur);
     path.translate(offset);
     QRectF fullSize = bounding.united(path.boundingRect());
-    m_shadow = QImage(fullSize.width() + qAbs(m_shadowOffset.x()) + m_shadowBlur, fullSize.height() + qAbs(m_shadowOffset.y()), QImage::Format_ARGB32_Premultiplied);
-    m_shadow.fill(Qt::transparent);
-    QPainter painter(&m_shadow);
+    QImage shadow(fullSize.width() + qAbs(m_shadowOffset.x()) + 4 * m_shadowBlur, fullSize.height() + qAbs(m_shadowOffset.y()) + 4 * m_shadowBlur, QImage::Format_ARGB32_Premultiplied);
+    shadow.fill(Qt::transparent);
+    QPainter painter(&shadow);
     painter.fillPath(path, QBrush(m_shadowColor));
     painter.end();
     if (m_shadowBlur > 0) {
-        blurShadow(m_shadow, m_shadowBlur);
+        blurShadow(shadow, m_shadowBlur);
     }
+    m_shadowEffect->setShadow(shadow);
 }
 
 void MyTextItem::blurShadow(QImage &result, int radius)
@@ -220,14 +253,6 @@ void MyTextItem::blurShadow(QImage &result, int radius)
     }
 }
 
-void MyTextItem::paint( QPainter *painter, const QStyleOptionGraphicsItem * option, QWidget* w)
-{
-    if (m_useShadow && !m_shadow.isNull()) {
-        painter->drawImage(0, 0, m_shadow);
-    }
-    QGraphicsTextItem::paint(painter, option, w);
-}
- 
 void MyTextItem::updateGeometry()
 {
     QPointF topRightPrev = boundingRect().topRight();
@@ -260,8 +285,10 @@ QRectF MyTextItem::baseBoundingRect() const
 QRectF MyTextItem::boundingRect() const
 {
     QRectF base = baseBoundingRect();
-    base.setRight(base.right() + m_shadowOffset.x());
-    base.setBottom(base.bottom() + m_shadowOffset.y());
+    if (m_shadowOffset.x() > 0)
+        base.setRight(base.right() + m_shadowOffset.x());
+    if (m_shadowOffset.y() > 0)
+        base.setBottom(base.bottom() + m_shadowOffset.y());
     return base;
 }
 
@@ -288,6 +315,28 @@ QVariant MyTextItem::itemChange(GraphicsItemChange change, const QVariant &value
     return QGraphicsItem::itemChange(change, value);
 }
 
+void MyTextItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *evt)
+{
+    if(textInteractionFlags() == Qt::TextEditorInteraction)
+    {
+        // if editor mode is already on: pass double click events on to the editor:
+        QGraphicsTextItem::mouseDoubleClickEvent(evt);
+        return;
+    }
+    // if editor mode is off:
+    // 1. turn editor mode on and set selected and focused:
+    //SetTextInteraction(true);
+    setTextInteractionFlags(Qt::TextEditorInteraction);
+    setFocus(Qt::MouseFocusReason);
+    // 2. send a single click to this QGraphicsTextItem (this will set the cursor to the mouse position):
+    // create a new mouse event with the same parameters as evt
+    QGraphicsSceneMouseEvent *click = new QGraphicsSceneMouseEvent(QEvent::GraphicsSceneMousePress);
+    click->setButton(evt->button());
+    click->setPos(evt->pos());
+    QGraphicsTextItem::mousePressEvent(click);
+    delete click; // don't forget to delete the event
+}
+
 MyRectItem::MyRectItem(QGraphicsItem *parent) :
     QGraphicsRectItem(parent)
 {
@@ -476,8 +525,6 @@ void GraphicsSceneRectMove::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* e)
     }
     if (g && g->type() == QGraphicsTextItem::Type && g->flags() & QGraphicsItem::ItemIsSelectable) {
         m_selectedItem = g;
-        MyTextItem *t = static_cast<MyTextItem *>(g);
-        t->setTextInteractionFlags(Qt::TextEditorInteraction);
     } else emit doubleClickEvent();
     QGraphicsScene::mouseDoubleClickEvent(e);
 }
@@ -525,7 +572,7 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
                 break;
             }
         }
-        if (item == NULL  || !(item->flags() & QGraphicsItem::ItemIsSelectable)) {
+        if (item == NULL  || m_selectedItem != item) {
             if (m_selectedItem && m_selectedItem->type() == QGraphicsTextItem::Type) {
                 // disable text editing
                 MyTextItem *t = static_cast<MyTextItem *>(m_selectedItem);
@@ -534,6 +581,8 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
                 t->setTextCursor(QTextCursor(cur));
                 t->setTextInteractionFlags(Qt::NoTextInteraction);
             }
+        }
+        if (item == NULL  || !(item->flags() & QGraphicsItem::ItemIsSelectable)) {
             m_selectedItem = NULL;
             foreach(QGraphicsItem* g, list) {
                 if (g->zValue() > -1000) {
@@ -672,7 +721,7 @@ void GraphicsSceneRectMove::mouseMoveEvent(QGraphicsSceneMouseEvent* e)
             }
 
             if (m_selectedItem->type() == QGraphicsRectItem::Type && m_resizeMode != NoResize) {
-                MyRectItem *gi = (MyRectItem*)m_selectedItem;
+                MyRectItem *gi = static_cast<MyRectItem*>(m_selectedItem);
                 // Resize using aspect ratio
                 if (!m_selectedItem->data(0).isNull()) {
                     // we want to keep aspect ratio
