@@ -30,7 +30,8 @@ KeyframeEdit::KeyframeEdit(const QDomElement &e, int minFrame, int maxFrame, con
     QWidget(parent),
     m_min(minFrame),
     m_max(maxFrame),
-    m_timecode(tc)
+    m_timecode(tc),
+    m_keyframesTag(false)
 {
     setupUi(this);
     if (m_max == -1) {
@@ -42,14 +43,14 @@ KeyframeEdit::KeyframeEdit(const QDomElement &e, int minFrame, int maxFrame, con
     buttonSeek->setChecked(KdenliveSettings::keyframeseek());
     connect(buttonSeek, SIGNAL(toggled(bool)), this, SLOT(slotSetSeeking(bool)));
 
-    buttonKeyframes->setIcon(KoIconUtils::themedIcon("chronometer"));
-    button_add->setIcon(KoIconUtils::themedIcon("list-add"));
+    buttonKeyframes->setIcon(KoIconUtils::themedIcon(QStringLiteral("chronometer")));
+    button_add->setIcon(KoIconUtils::themedIcon(QStringLiteral("list-add")));
     button_add->setToolTip(i18n("Add keyframe"));
-    button_delete->setIcon(KoIconUtils::themedIcon("list-remove"));
+    button_delete->setIcon(KoIconUtils::themedIcon(QStringLiteral("list-remove")));
     button_delete->setToolTip(i18n("Delete keyframe"));
-    buttonResetKeyframe->setIcon(KoIconUtils::themedIcon("edit-undo"));
-    buttonSeek->setIcon(KoIconUtils::themedIcon("edit-link"));
-    connect(keyframe_list, SIGNAL(itemSelectionChanged()), this, SLOT(slotAdjustKeyframeInfo()));
+    buttonResetKeyframe->setIcon(KoIconUtils::themedIcon(QStringLiteral("edit-undo")));
+    buttonSeek->setIcon(KoIconUtils::themedIcon(QStringLiteral("edit-link")));
+    connect(keyframe_list, &QTableWidget::cellActivated, this, &KeyframeEdit::rowClicked);
     connect(keyframe_list, SIGNAL(cellChanged(int,int)), this, SLOT(slotGenerateParams(int,int)));
 
     m_position = new PositionEdit(i18n("Position"), 0, 0, 1, tc, widgetTable);
@@ -107,29 +108,42 @@ void KeyframeEdit::addParameter(const QDomElement &e, int activeKeyframe)
     keyframe_list->blockSignals(true);
     m_params.append(e.cloneNode().toElement());
 
-    QDomElement na = e.firstChildElement("name");
+    QDomElement na = e.firstChildElement(QStringLiteral("name"));
     QString paramName = i18n(na.text().toUtf8().data());
-    QDomElement commentElem = e.firstChildElement("comment");
+    QDomElement commentElem = e.firstChildElement(QStringLiteral("comment"));
     QString comment;
     if (!commentElem.isNull())
         comment = i18n(commentElem.text().toUtf8().data());
-    
+
     int columnId = keyframe_list->columnCount();
     keyframe_list->insertColumn(columnId);
     keyframe_list->setHorizontalHeaderItem(columnId, new QTableWidgetItem(paramName));
 
     DoubleParameterWidget *doubleparam = new DoubleParameterWidget(paramName, 0,
-                                                                   m_params.at(columnId).attribute("min").toDouble(), m_params.at(columnId).attribute("max").toDouble(),
-                                                                   m_params.at(columnId).attribute("default").toDouble(), comment, columnId, m_params.at(columnId).attribute("suffix"), m_params.at(columnId).attribute("decimals").toInt(), this);
+                                                                   m_params.at(columnId).attribute(QStringLiteral("min")).toDouble(), m_params.at(columnId).attribute(QStringLiteral("max")).toDouble(),
+                                                                   m_params.at(columnId).attribute(QStringLiteral("default")).toDouble(), comment, columnId, m_params.at(columnId).attribute(QStringLiteral("suffix")), m_params.at(columnId).attribute(QStringLiteral("decimals")).toInt(), false, this);
     connect(doubleparam, SIGNAL(valueChanged(double)), this, SLOT(slotAdjustKeyframeValue(double)));
     connect(this, SIGNAL(showComments(bool)), doubleparam, SLOT(slotShowComment(bool)));
     connect(doubleparam, SIGNAL(setInTimeline(int)), this, SLOT(slotUpdateVisibleParameter(int)));
     m_slidersLayout->addWidget(doubleparam, columnId, 0);
-    if (e.attribute("intimeline") == "1") {
+    if (e.attribute(QStringLiteral("intimeline")) == QLatin1String("1")) {
         doubleparam->setInTimelineProperty(true);
     }
 
-    QStringList frames = e.attribute("keyframes").split(';', QString::SkipEmptyParts);
+    QStringList frames;
+    if (e.hasAttribute(QStringLiteral("keyframes"))) {
+        // Effects have keyframes in a "keyframe" attribute, not sure why
+        frames = e.attribute(QStringLiteral("keyframes")).split(';', QString::SkipEmptyParts);
+        m_keyframesTag = true;
+    } else {
+        // Transitions take keyframes from the value param
+        QString framesValue = e.attribute(QStringLiteral("value"));
+        if (!framesValue.contains(QStringLiteral("="))) {
+            framesValue.prepend(QStringLiteral("0="));
+        }
+        frames = framesValue.split(';', QString::SkipEmptyParts);
+        m_keyframesTag = false;
+    }
     for (int i = 0; i < frames.count(); ++i) {
         int frame = frames.at(i).section('=', 0, 0).toInt();
         bool found = false;
@@ -155,6 +169,10 @@ void KeyframeEdit::addParameter(const QDomElement &e, int activeKeyframe)
             keyframe_list->selectRow(i);
         }
     }
+    if (!keyframe_list->currentItem()) {
+        keyframe_list->setCurrentCell(0, columnId);
+        keyframe_list->selectRow(0);
+    }
     keyframe_list->resizeColumnsToContents();
     keyframe_list->blockSignals(false);
     keyframe_list->horizontalHeader()->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
@@ -182,50 +200,91 @@ void KeyframeEdit::slotDeleteKeyframe()
     buttonKeyframes->setHidden(!disable);
 }
 
-void KeyframeEdit::slotAddKeyframe()
+void KeyframeEdit::slotAddKeyframe(int pos)
 {
     keyframe_list->blockSignals(true);
-    QTableWidgetItem *item = keyframe_list->currentItem();
-    int row = keyframe_list->currentRow();
+    int row = 0;
     int col = keyframe_list->currentColumn();
     int newrow = row;
-    int pos1 = getPos(row);
-
-    int result;
-    if (row < (keyframe_list->rowCount() - 1)) {
-        result = pos1 + (getPos(row + 1) - pos1) / 2;
-        newrow++;
-    } else if (row == 0) {
-        if (pos1 == m_min) {
-            result = m_max;
-            newrow++;
-        } else {
-            result = m_min;
+    int result = pos;
+    if (result > 0) {
+        // A position was provided
+        for (; newrow < keyframe_list->rowCount(); newrow++) {
+            int rowPos = getPos(newrow);
+            if (rowPos > result) {
+                break;
+            }
         }
     } else {
-        if (pos1 < m_max) {
-            // last keyframe selected and it is not at end of clip -> add keyframe at the end
-            result = m_max;
+        row = keyframe_list->currentRow();
+        newrow = row;
+        int pos1 = getPos(row);
+        if (row < (keyframe_list->rowCount() - 1)) {
+            result = pos1 + (getPos(row + 1) - pos1) / 2;
             newrow++;
+        } else if (row == 0) {
+            if (pos1 == m_min) {
+                result = m_max;
+                newrow++;
+            } else {
+                result = m_min;
+            }
         } else {
-            int pos2 = getPos(row - 1);
-            result = pos2 + (pos1 - pos2) / 2;
+            if (pos1 < m_max) {
+                // last keyframe selected and it is not at end of clip -> add keyframe at the end
+                result = m_max;
+                newrow++;
+            } else {
+                int pos2 = getPos(row - 1);
+                result = pos2 + (pos1 - pos2) / 2;
+            }
         }
     }
-
+    // Calculate new values
+    QList <double> previousValues;
+    QList <double> nextValues;
+    int rowCount = keyframe_list->rowCount();
+    // Insert new row
     keyframe_list->insertRow(newrow);
     keyframe_list->setVerticalHeaderItem(newrow, new QTableWidgetItem(getPosString(result)));
-    for (int i = 0; i < keyframe_list->columnCount(); ++i)
-        keyframe_list->setItem(newrow, i, new QTableWidgetItem(keyframe_list->item(item->row(), i)->text()));
 
+    // If keyframe is inserted at start
+    if (newrow == 0) {
+        for (int i = 0; i < keyframe_list->columnCount(); ++i) {
+            int newValue = keyframe_list->item(1, i)->text().toDouble();
+            keyframe_list->setItem(newrow, i, new QTableWidgetItem(QString::number(newValue)));
+        }
+    } else if (newrow == rowCount){
+        // Keyframe inserted at end
+        for (int i = 0; i < keyframe_list->columnCount(); ++i) {
+            int newValue = keyframe_list->item(rowCount - 1, i)->text().toDouble();
+            keyframe_list->setItem(newrow, i, new QTableWidgetItem(QString::number(newValue)));
+        }
+    } else {
+        // Interpolate
+        int previousPos = getPos(newrow - 1);
+        int nextPos = getPos(newrow + 1);
+        if (nextPos > previousPos) {
+            double factor = ((double) result - previousPos) / (nextPos - previousPos);
+
+            for (int i = 0; i < keyframe_list->columnCount(); ++i) {
+                double previousValues = keyframe_list->item(newrow - 1, i)->text().toDouble();
+                double nextValues = keyframe_list->item(newrow + 1, i)->text().toDouble();
+                int newValue = (int) (previousValues + (nextValues- previousValues) * factor);
+                keyframe_list->setItem(newrow, i, new QTableWidgetItem(QString::number(newValue)));
+            }
+        }
+    }
     keyframe_list->resizeRowsToContents();
+    keyframe_list->setCurrentCell(newrow, col);
     slotAdjustKeyframeInfo();
     keyframe_list->blockSignals(false);
     generateAllParams();
+    if (rowCount == 1) {
+        // there was only one keyframe before, so now enable keyframe mode
+        slotKeyframeMode();
+    }
     button_delete->setEnabled(keyframe_list->rowCount() > 1);
-    keyframe_list->setCurrentCell(newrow, col);
-    keyframe_list->selectRow(newrow);
-    //slotGenerateParams(newrow, 0);
 }
 
 void KeyframeEdit::slotGenerateParams(int row, int column)
@@ -249,16 +308,16 @@ void KeyframeEdit::slotGenerateParams(int row, int column)
             item = keyframe_list->item(row, col);
             if (!item) continue;
             int v = item->text().toInt();
-            if (v >= m_params.at(col).attribute("max").toInt())
-                item->setText(m_params.at(col).attribute("max"));
-            if (v <= m_params.at(col).attribute("min").toInt())
-                item->setText(m_params.at(col).attribute("min"));
+            if (v >= m_params.at(col).attribute(QStringLiteral("max")).toInt())
+                item->setText(m_params.at(col).attribute(QStringLiteral("max")));
+            if (v <= m_params.at(col).attribute(QStringLiteral("min")).toInt())
+                item->setText(m_params.at(col).attribute(QStringLiteral("min")));
             QString keyframes;
             for (int i = 0; i < keyframe_list->rowCount(); ++i) {
                 if (keyframe_list->item(i, col))
                     keyframes.append(QString::number(getPos(i)) + '=' + keyframe_list->item(i, col)->text() + ';');
             }
-            m_params[col].setAttribute("keyframes", keyframes);
+            m_params[col].setAttribute(getTag(), keyframes);
         }
 
         emit parameterChanged();
@@ -285,10 +344,10 @@ void KeyframeEdit::slotGenerateParams(int row, int column)
         keyframe_list->verticalHeaderItem(row)->setText(val);
 
     int v = item->text().toInt();
-    if (v >= m_params.at(column).attribute("max").toInt())
-        item->setText(m_params.at(column).attribute("max"));
-    if (v <= m_params.at(column).attribute("min").toInt())
-        item->setText(m_params.at(column).attribute("min"));
+    if (v >= m_params.at(column).attribute(QStringLiteral("max")).toInt())
+        item->setText(m_params.at(column).attribute(QStringLiteral("max")));
+    if (v <= m_params.at(column).attribute(QStringLiteral("min")).toInt())
+        item->setText(m_params.at(column).attribute(QStringLiteral("min")));
     slotAdjustKeyframeInfo(false);
 
     QString keyframes;
@@ -296,10 +355,16 @@ void KeyframeEdit::slotGenerateParams(int row, int column)
         if (keyframe_list->item(i, column))
             keyframes.append(QString::number(getPos(i)) + '=' + keyframe_list->item(i, column)->text() + ';');
     }
-    m_params[column].setAttribute("keyframes", keyframes);
+    m_params[column].setAttribute(getTag(), keyframes);
     emit parameterChanged();
 }
 
+const QString KeyframeEdit::getTag() const
+{
+    QString tag = m_keyframesTag == true ? QStringLiteral("keyframes") : QStringLiteral("value");
+    return tag;
+}
+
 void KeyframeEdit::generateAllParams()
 {
     for (int col = 0; col < keyframe_list->columnCount(); ++col) {
@@ -308,7 +373,7 @@ void KeyframeEdit::generateAllParams()
             if (keyframe_list->item(i, col))
                 keyframes.append(QString::number(getPos(i)) + '=' + keyframe_list->item(i, col)->text() + ';');
         }
-        m_params[col].setAttribute("keyframes", keyframes);
+        m_params[col].setAttribute(getTag(), keyframes);
     }
     emit parameterChanged();
 }
@@ -316,10 +381,10 @@ void KeyframeEdit::generateAllParams()
 const QString KeyframeEdit::getValue(const QString &name)
 {
     for (int col = 0; col < keyframe_list->columnCount(); ++col) {
-        QDomNode na = m_params.at(col).firstChildElement("name");
+        QDomNode na = m_params.at(col).firstChildElement(QStringLiteral("name"));
         QString paramName = i18n(na.toElement().text().toUtf8().data());
         if (paramName == name)
-            return m_params.at(col).attribute("keyframes");
+            return m_params.at(col).attribute(getTag());
     }
     return QString();
 }
@@ -342,6 +407,7 @@ void KeyframeEdit::slotAdjustKeyframeInfo(bool seek)
     m_position->setRange(min, max, true);
     m_position->setPosition(getPos(item->row()));
     m_position->blockSignals(false);
+    QLocale locale;
 
     for (int col = 0; col < keyframe_list->columnCount(); ++col) {
         DoubleParameterWidget *doubleparam = static_cast <DoubleParameterWidget*>(m_slidersLayout->itemAtPosition(col, 0)->widget());
@@ -349,7 +415,7 @@ void KeyframeEdit::slotAdjustKeyframeInfo(bool seek)
             continue;
         doubleparam->blockSignals(true);
         if (keyframe_list->item(item->row(), col)) {
-            doubleparam->setValue(keyframe_list->item(item->row(), col)->text().toDouble());
+            doubleparam->setValue(locale.toDouble(keyframe_list->item(item->row(), col)->text()));
         } else {
             //qDebug() << "Null pointer exception caught: http://www.kdenlive.org/mantis/view.php?id=1771";
         }
@@ -426,7 +492,9 @@ void KeyframeEdit::slotKeyframeMode()
 {
     widgetTable->setHidden(false);
     buttonKeyframes->setHidden(true);
-    slotAddKeyframe();
+    if (keyframe_list->rowCount() == 1) {
+        slotAddKeyframe();
+    }
 }
 
 void KeyframeEdit::slotResetKeyframe()
@@ -441,7 +509,7 @@ void KeyframeEdit::slotResetKeyframe()
 void KeyframeEdit::slotUpdateVisibleParameter(int id, bool update)
 {
     for (int i = 0; i < m_params.count(); ++i) {
-        m_params[i].setAttribute("intimeline", (i == id ? "1" : "0"));
+        m_params[i].setAttribute(QStringLiteral("intimeline"), (i == id ? "1" : "0"));
     }
     for (int col = 0; col < keyframe_list->columnCount(); ++col) {
         DoubleParameterWidget *doubleparam = static_cast <DoubleParameterWidget*>(m_slidersLayout->itemAtPosition(col, 0)->widget());
@@ -457,10 +525,10 @@ void KeyframeEdit::slotUpdateVisibleParameter(int id, bool update)
 bool KeyframeEdit::isVisibleParam(const QString& name)
 {
     for (int col = 0; col < keyframe_list->columnCount(); ++col) {
-        QDomNode na = m_params.at(col).firstChildElement("name");
+        QDomNode na = m_params.at(col).firstChildElement(QStringLiteral("name"));
         QString paramName = i18n(na.toElement().text().toUtf8().data());
         if (paramName == name)
-            return m_params.at(col).attribute("intimeline") == "1";
+            return m_params.at(col).attribute(QStringLiteral("intimeline")) == QLatin1String("1");
     }
     return false;
 }
@@ -469,9 +537,8 @@ void KeyframeEdit::checkVisibleParam()
 {
     if (m_params.count() == 0)
         return;
-    
     foreach(const QDomElement &elem, m_params) {
-        if (elem.attribute("intimeline") == "1")
+        if (elem.attribute(QStringLiteral("intimeline")) == QLatin1String("1"))
             return;
     }
 
@@ -484,4 +551,7 @@ void KeyframeEdit::slotUpdateRange(int inPoint, int outPoint)
     m_max = outPoint;
 }
 
-
+void KeyframeEdit::rowClicked(int, int)
+{
+    slotAdjustKeyframeInfo(true);
+}
