@@ -21,7 +21,9 @@
 #include "kdenlivesettings.h"
 
 #include <QMouseEvent>
+#include <QLayout>
 #include <QLineEdit>
+#include <QStyle>
 #include <QFontDatabase>
 
 #include <KColorScheme>
@@ -34,17 +36,21 @@ TimecodeDisplay::TimecodeDisplay(const Timecode& t, QWidget *parent)
         m_maximum(-1),
         m_value(0)
 {
-    lineEdit()->setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
+    QFont ft = QFontDatabase::systemFont(QFontDatabase::FixedFont);
+    lineEdit()->setFont(ft);
+    setFont(ft);
     lineEdit()->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    QFontMetrics fm = lineEdit()->fontMetrics();
-    setMinimumWidth(fm.width("88:88:88:88888888") + contentsMargins().right() + contentsMargins().right());
-    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
-    setAccelerated(true);
-
-    setValue(m_minimum);
-
+    QFontMetrics fm(ft);
+    setFrame(false);
+    QPalette palette;
+    palette.setColor(QPalette::Base, Qt::transparent);//palette.window().color());
+    setPalette(palette);
     setTimeCodeFormat(KdenliveSettings::frametimecode(), true);
+    setValue(m_minimum);
+    setMinimumWidth(fm.width(QStringLiteral("88:88:88:88")) + contentsMargins().right() + contentsMargins().left() + frameSize().width() - lineEdit()->contentsRect().width() + QStyle::PM_SpinBoxFrameWidth + 6);
 
+    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Maximum);
+    setAccelerated(true);
     connect(lineEdit(), SIGNAL(editingFinished()), this, SLOT(slotEditingFinished()));
 }
 
@@ -117,6 +123,17 @@ void TimecodeDisplay::wheelEvent(QWheelEvent *e)
     clearFocus();
 }
 
+void TimecodeDisplay::enterEvent(QEvent *e)
+{
+    QAbstractSpinBox::enterEvent(e);
+    setFrame(true);
+}
+
+void TimecodeDisplay::leaveEvent(QEvent *e)
+{
+    QAbstractSpinBox::leaveEvent(e);
+    setFrame(false);
+}
 
 int TimecodeDisplay::maximum() const
 {
@@ -156,10 +173,11 @@ void TimecodeDisplay::setValue(const QString &value)
 
 void TimecodeDisplay::setValue(int value)
 {
-    if (value < m_minimum)
-        value = m_minimum;
-    if (m_maximum > m_minimum && value > m_maximum)
-        value = m_maximum;
+    if (m_maximum > 0) {
+        value = qBound(m_minimum, value, m_maximum);
+    } else {
+        value = qMax(m_minimum, value);
+    }
 
     if (m_frametimecode) {
 	if (value == m_value && !lineEdit()->text().isEmpty()) return;
@@ -167,7 +185,7 @@ void TimecodeDisplay::setValue(int value)
         lineEdit()->setText(QString::number(value));
     }
     else {
-	if (value == m_value && lineEdit()->text() != ":::") return;
+	if (value == m_value && lineEdit()->text() != QLatin1String(":::")) return;
 	m_value = value;
         QString v = m_timecode.getTimecodeFromFrames(value);
         lineEdit()->setText(v);
@@ -179,6 +197,14 @@ void TimecodeDisplay::setValue(const GenTime &value)
     setValue((int) value.frames(m_timecode.fps()));
 }
 
+void TimecodeDisplay::sendTimecode(bool send)
+{
+    if (send) {
+        connect(lineEdit(), &QLineEdit::textChanged, this, &TimecodeDisplay::emitTimeCode, Qt::UniqueConnection);
+    } else {
+        disconnect(lineEdit(), &QLineEdit::textChanged, this, &TimecodeDisplay::emitTimeCode);
+    }
+}
 
 void TimecodeDisplay::slotEditingFinished()
 {
@@ -188,3 +214,8 @@ void TimecodeDisplay::slotEditingFinished()
     emit timeCodeEditingFinished(m_value);
 }
 
+const QString TimecodeDisplay::displayText() const
+{
+    return lineEdit()->displayText();
+}
+
