@@ -235,7 +235,11 @@ void HeaderTrack::setSelectedIndex(int ix)
 void HeaderTrack::adjustSize(int height)
 {
     // Don't show track buttons if size is too small
-    bool smallTracks = height < 40;
+    QFontMetrics metrics(font());
+    int trackHeight = metrics.height();
+    QStyle *style = qApp->style();
+    trackHeight += style->pixelMetric(QStyle::PM_ToolBarIconSize);
+    bool smallTracks = height < trackHeight;
     m_tb->setHidden(smallTracks);
     setFixedHeight(height);
 }
@@ -262,7 +266,9 @@ void HeaderTrack::switchLock(bool enable)
 
 void HeaderTrack::setLock(bool lock)
 {
+    m_switchLock->blockSignals(true);
     m_switchLock->setActive(lock);
+    m_switchLock->blockSignals(false);
 }
 
 void HeaderTrack::disableComposite()
