@@ -608,6 +608,15 @@ QList <TrackInfo> Timeline::getTracksInfo()
     return tracks;
 }
 
+QStringList Timeline::getTrackNames()
+{
+    QStringList trackNames;
+    for (int i = 0; i < tracksCount(); i++) {
+        trackNames << track(i)->info().trackName;
+    }
+    return trackNames;
+}
+
 void Timeline::lockTrack(int ix, bool lock)
 {
     Track *tk = track(ix);
@@ -629,19 +638,6 @@ bool Timeline::isTrackLocked(int ix)
     return locked == 1;
 }
 
-int Timeline::getTrackIndex(const QString &id)
-{
-    for (int i = 0; i < m_tractor->count(); i++) {
-        QScopedPointer<Mlt::Producer> track(m_tractor->track(i));
-        QString mltTrackName = track->get("producer");
-        if (mltTrackName == id) {
-            return i;
-        }
-    }
-    return -1;
-
-}
-
 void Timeline::updateTrackState(int ix, int state)
 {
     int currentState = 0;
@@ -777,15 +773,6 @@ void Timeline::switchTrackAudio(int ix, bool mute)
     m_tractor->refresh();
 }
 
-int Timeline::getLowestNonMutedAudioTrack()
-{
-    for (int i = 1; i < m_tracks.count(); ++i) {
-        Track *tk = track(i);
-        if (tk->state() < 2) return i;
-    }
-    return m_tracks.count();
-}
-
 int Timeline::getLowestVideoTrack()
 {
     for (int i = 1; i < m_tracks.count(); ++i) {
