@@ -53,11 +53,6 @@ Mlt::Playlist & Track::playlist()
     return m_playlist;
 }
 
-void Track::setPlaylist(Mlt::Playlist &playlist)
-{
-    m_playlist = playlist;
-}
-
 qreal Track::fps()
 {
     return m_playlist.get_fps();
@@ -631,24 +626,26 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
     int startPos = info.startPos.frames(fps());
     int clipIndex = m_playlist.get_clip_index_at(startPos);
     int clipLength = m_playlist.clip_length(clipIndex);
-
+    m_playlist.lock();
     QScopedPointer<Mlt::Producer> original(m_playlist.get_clip(clipIndex));
     if (original == NULL) {
         qDebug()<<"// No clip to apply effect";
+        m_playlist.unlock();
         return -1;
     }
     if (!original->is_valid() || original->is_blank()) {
         // invalid clip
         qDebug()<<"// Invalid clip to apply effect";
+        m_playlist.unlock();
         return -1;
     }
     Mlt::Producer clipparent = original->parent();
     if (!clipparent.is_valid() || clipparent.is_blank()) {
         // invalid clip
         qDebug()<<"// Invalid parent to apply effect";
+        m_playlist.unlock();
         return -1;
     }
-
     QLocale locale;
     if (speed <= 0 && speed > -1) speed = 1.0;
     QString serv = clipparent.get("mlt_service");
@@ -665,12 +662,12 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
     slowInfo.state = state;
     if (serv.contains(QStringLiteral("avformat"))) {
 	if (speed != 1.0 || strobe > 1) {
-	    m_playlist.lock();
 	    if (!prod || !prod->is_valid()) {
 		prod = buildSlowMoProducer(passProps, url, id, slowInfo);
                 if (prod == NULL) {
                     // error, abort
                     qDebug()<<"++++ FAILED TO CREATE SLOWMO PROD";
+                    m_playlist.unlock();
                     return -1;
                 }
 	    }
@@ -692,10 +689,7 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
 	    delete cut;
 	    clipIndex = m_playlist.get_clip_index_at(startPos);
 	    newLength = m_playlist.clip_length(clipIndex);
-	    m_playlist.unlock();
 	} else if (speed == 1.0 && strobe < 2) {
-	    m_playlist.lock();
-
 	    QScopedPointer <Mlt::Producer> clip(m_playlist.replace_with_blank(clipIndex));
 	    m_playlist.consolidate_blanks(0);
 
@@ -710,9 +704,10 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
                 if (prod == NULL) {
                     // error, abort
                     qDebug()<<"++++ FAILED TO CREATE SLOWMO PROD";
+                    m_playlist.unlock();
                     return -1;
                 }
-	    }
+            }
 
 	    int originalStart = (int)(speedIndependantInfo.cropStart.frames(fps()));
 	    if (clipIndex + 1 < m_playlist.count() && (info.startPos + speedIndependantInfo.cropDuration).frames(fps()) > blankEnd) {
@@ -728,15 +723,14 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
 	    delete cut;
 	    clipIndex = m_playlist.get_clip_index_at(startPos);
 	    newLength = m_playlist.clip_length(clipIndex);
-	    m_playlist.unlock();
 	}
     } else if (serv == QLatin1String("timewarp")) {
-        m_playlist.lock();
         if (!prod || !prod->is_valid()) {
             prod = buildSlowMoProducer(passProps, url, id, slowInfo);
             if (prod == NULL) {
                 // error, abort
                 qDebug()<<"++++ FAILED TO CREATE SLOWMO PROD";
+                m_playlist.unlock();
                 return -1;
             }
         }
@@ -754,7 +748,7 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
           duration = (int) (speedIndependantInfo.cropDuration.frames(fps()) / speed + 0.5);
           originalStart = (int)(speedIndependantInfo.cropStart.frames(fps()) / speed + 0.5);
         }
-        qDebug()<<"/ / /UPDATE SPEED: "<<speed<<", "<<speedIndependantInfo.cropStart.frames(fps())<<":"<<originalStart;
+        //qDebug()<<"/ / /UPDATE SPEED: "<<speed<<", "<<speedIndependantInfo.cropStart.frames(fps())<<":"<<originalStart;
         // Check that the blank space is long enough for our new duration
         clipIndex = m_playlist.get_clip_index_at(startPos);
         int blankEnd = m_playlist.clip_start(clipIndex) + m_playlist.clip_length(clipIndex);
@@ -773,8 +767,11 @@ int Track::changeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, Playlis
         delete cut;
         clipIndex = m_playlist.get_clip_index_at(startPos);
         newLength = m_playlist.clip_length(clipIndex);
-        m_playlist.unlock();
+        if (removeEffect)
+            delete prod;
     }
+    //Do not delete prod, it is now stored in the slowmotion producers list
+    m_playlist.unlock();
     if (clipIndex + 1 == m_playlist.count()) {
         // We changed the speed of last clip in playlist, check track length
         emit newTrackDuration(m_playlist.get_playtime());
